from __future__ import unicode_literals


__author__ = 'Michele Matera'
__version__ = '0.5'


default_app_config = 'djangodaylessdate.apps.DjangoDaylessDateConfig'


VERSION = __version__